@@ -12,31 +12,30 @@
 #    under the License.
 
 import email
-import uuid
-
 import mock
 
-from heat.common import exception as exc
-from heat.engine.resources.openstack.heat import multi_part as mp
-from heat.engine import stack as parser
+from heat.engine import parser
 from heat.engine import template
-from heat.tests import common
+
+import heat.engine.resources.software_config.multi_part as mp
+
+from heat.tests.common import HeatTestCase
 from heat.tests import utils
+import heatclient.exc as exc
 
 
-class MultipartMimeTest(common.HeatTestCase):
+class MultipartMimeTest(HeatTestCase):
 
     def setUp(self):
         super(MultipartMimeTest, self).setUp()
+        utils.setup_dummy_db()
         self.ctx = utils.dummy_context()
         self.init_config()
 
-    def init_config(self, parts=None):
-        parts = parts or []
+    def init_config(self, parts=[]):
         stack = parser.Stack(
             self.ctx, 'software_config_test_stack',
             template.Template({
-                'HeatTemplateFormatVersion': '2012-12-12',
                 'Resources': {
                     'config_mysql': {
                         'Type': 'OS::Heat::MultipartMime',
@@ -44,8 +43,9 @@ class MultipartMimeTest(common.HeatTestCase):
                             'parts': parts
                         }}}}))
         self.config = stack['config_mysql']
-        self.rpc_client = mock.MagicMock()
-        self.config._rpc_client = self.rpc_client
+        heat = mock.MagicMock()
+        self.config.heat = heat
+        self.software_configs = heat.return_value.software_configs
 
     def test_resource_mapping(self):
         mapping = mp.resource_mapping()
@@ -55,19 +55,14 @@ class MultipartMimeTest(common.HeatTestCase):
         self.assertIsInstance(self.config, mp.MultipartMime)
 
     def test_handle_create(self):
+        sc = mock.MagicMock()
         config_id = 'c8a19429-7fde-47ea-a42f-40045488226c'
-        sc = {'id': config_id}
-        self.rpc_client.create_software_config.return_value = sc
-        self.config.id = 55
-        self.config.uuid = uuid.uuid4().hex
+        sc.id = config_id
+        self.software_configs.create.return_value = sc
         self.config.handle_create()
         self.assertEqual(config_id, self.config.resource_id)
-        kwargs = self.rpc_client.create_software_config.call_args[1]
-        self.assertEqual({
-            'name': self.config.physical_resource_name(),
-            'config': self.config.message,
-            'group': 'Heat::Ungrouped'
-        }, kwargs)
+        args = self.software_configs.create.call_args[1]
+        self.assertEqual(self.config.message, args['config'])
 
     def test_get_message_not_none(self):
         self.config.message = 'Not none'
@@ -87,14 +82,8 @@ class MultipartMimeTest(common.HeatTestCase):
             'type': 'text'
         }]
         self.init_config(parts=parts)
-        self.rpc_client.show_software_config.return_value = {
-            'config': '#!/bin/bash'
-        }
+        self.software_configs.get.return_value.config = '#!/bin/bash'
         result = self.config.get_message()
-        self.assertEqual(
-            '1e0e5a60-2843-4cfd-9137-d90bdf18eef5',
-            self.rpc_client.show_software_config.call_args[0][1])
-
         message = email.message_from_string(result)
         self.assertTrue(message.is_multipart())
         subs = message.get_payload()
@@ -103,36 +92,17 @@ class MultipartMimeTest(common.HeatTestCase):
 
     def test_get_message_fail_back(self):
         parts = [{
-            'config': '2e0e5a60-2843-4cfd-9137-d90bdf18eef5',
+            'config': '#!/bin/bash',
             'type': 'text'
         }]
         self.init_config(parts=parts)
-        self.rpc_client.show_software_config.side_effect = exc.NotFound()
-        result = self.config.get_message()
-
-        self.assertEqual(
-            '2e0e5a60-2843-4cfd-9137-d90bdf18eef5',
-            self.rpc_client.show_software_config.call_args[0][1])
-
-        message = email.message_from_string(result)
-        self.assertTrue(message.is_multipart())
-        subs = message.get_payload()
-        self.assertEqual(1, len(subs))
-        self.assertEqual('2e0e5a60-2843-4cfd-9137-d90bdf18eef5',
-                         subs[0].get_payload())
-
-    def test_get_message_non_uuid(self):
-        parts = [{
-            'config': 'http://192.168.122.36:8000/v1/waitcondition/'
-        }]
-        self.init_config(parts=parts)
+        self.software_configs.get.side_effect = exc.HTTPNotFound()
         result = self.config.get_message()
         message = email.message_from_string(result)
         self.assertTrue(message.is_multipart())
         subs = message.get_payload()
         self.assertEqual(1, len(subs))
-        self.assertEqual('http://192.168.122.36:8000/v1/waitcondition/',
-                         subs[0].get_payload())
+        self.assertEqual('#!/bin/bash', subs[0].get_payload())
 
     def test_get_message_text_with_filename(self):
         parts = [{
@@ -141,15 +111,8 @@ class MultipartMimeTest(common.HeatTestCase):
             'filename': '/opt/stack/configure.d/55-heat-config'
         }]
         self.init_config(parts=parts)
-        self.rpc_client.show_software_config.return_value = {
-            'config': '#!/bin/bash'
-        }
+        self.software_configs.get.return_value.config = '#!/bin/bash'
         result = self.config.get_message()
-
-        self.assertEqual(
-            '1e0e5a60-2843-4cfd-9137-d90bdf18eef5',
-            self.rpc_client.show_software_config.call_args[0][1])
-
         message = email.message_from_string(result)
         self.assertTrue(message.is_multipart())
         subs = message.get_payload()
@@ -175,17 +138,8 @@ class MultipartMimeTest(common.HeatTestCase):
             'type': 'multipart'
         }]
         self.init_config(parts=parts)
-
-        self.rpc_client.show_software_config.return_value = {
-            'config': multipart
-        }
-
+        self.software_configs.get.return_value.config = multipart
         result = self.config.get_message()
-
-        self.assertEqual(
-            '1e0e5a60-2843-4cfd-9137-d90bdf18eef5',
-            self.rpc_client.show_software_config.call_args[0][1])
-
         message = email.message_from_string(result)
         self.assertTrue(message.is_multipart())
         subs = message.get_payload()
@@ -201,18 +155,8 @@ class MultipartMimeTest(common.HeatTestCase):
             {'config': '9cab10ef-16ce-4be9-8b25-a67b7313eddb',
              'type': 'text'}]
         self.init_config(parts=parts)
-        self.rpc_client.show_software_config.return_value = {
-            'config': '#!/bin/bash'
-        }
+        self.software_configs.get.return_value.config = '#!/bin/bash'
         result = self.config.get_message()
-
-        self.assertEqual(
-            '1e0e5a60-2843-4cfd-9137-d90bdf18eef5',
-            self.rpc_client.show_software_config.call_args_list[0][0][1])
-        self.assertEqual(
-            '9cab10ef-16ce-4be9-8b25-a67b7313eddb',
-            self.rpc_client.show_software_config.call_args_list[1][0][1])
-
         message = email.message_from_string(result)
         self.assertTrue(message.is_multipart())
         subs = message.get_payload()
